==> mgodd-2.3.1.tgz: package/lib/install.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var getLatestVer = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
    var ver;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return axios({
              method: 'get',
              url: 'https://ssr.alpha.elenet.me/mongo-dal/getLatestVer'
            });

          case 2:
            ver = _context2.sent.data;
            return _context2.abrupt('return', ver);

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function getLatestVer() {
    return _ref2.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var https = require('https');
var os = require('os');
var path = require('path');
var fs = require('fs');
var axios = require('axios');
var ProgressBar = require('progress');

function downMgoDal() {
  var _this = this;

  return new Promise(function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regenerator2.default.mark(function _callee(resolve, reject) {
      var ver, reqUrl;
      return _regenerator2.default.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.t0 = process.env.MONGO_DAL_DOWNLOAD_VER;

              if (_context.t0) {
                _context.next = 5;
                break;
              }

              _context.next = 4;
              return getLatestVer();

            case 4:
              _context.t0 = _context.sent;

            case 5:
              ver = _context.t0;
              reqUrl = getDownUrl(ver);


              console.log("download url: ", reqUrl);

              https.get(reqUrl, function (res) {
                try {
                  var resCode = res.statusCode;
                  if (/^(?:4|5)\d{2}$/.test(String(resCode))) {
                    return reject(`download error with code: ${resCode}`);
                  }
                  var writeStream = createFile(reqUrl);
                  var totalBytes = parseInt(res.headers['content-length'], 10);
                  var progressBar = null;

                  res.pipe(writeStream);
                  res.on('data', function (data) {
                    if (!progressBar) {
                      progressBar = new ProgressBar(`Downloading ${getFileName(reqUrl)} ${toMegabytes(totalBytes)} [:bar] :percent :etas `, {
                        complete: '=',
                        incomplete: ' ',
                        width: 20,
                        total: totalBytes
                      });
                    }

                    progressBar.tick(data.length);
                  });
                  res.on('end', function () {
                    try {
                      fs.writeFileSync(path.resolve(__dirname, '../.mongodal_ver'), ver);
                      resolve();
                    } catch (err) {
                      reject(err);
                    }
                  });
                } catch (err) {
                  return reject(err);
                }
              }).on('error', reject);

            case 9:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, _this);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }());
}

function toMegabytes(bytes) {
  var mb = bytes / 1024 / 1024;
  return `${Math.round(mb * 10) / 10} Mb`;
}

function getDownUrl(ver) {
  return `https://shadow.elemecdn.com/app/mongo-dal/mongo-dal@${ver}/mongo-dal-${os.platform()}`;
}

function createFile() {
  var reqUrl = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  var fName = getFileName(reqUrl);

  if (!fName) {
    throw new Error('file name error');
  }

  var binDir = path.resolve(__dirname, '../bin');
  try {
    fs.mkdirSync(binDir, 0o755);
  } catch (_) {}

  return fs.createWriteStream(path.resolve(binDir, fName), { mode: 0o755 });
}

function getFileName(reqUrl) {
  var matchVals = reqUrl.match(/\/(mongo-dal@.+?)\//);
  var fName = matchVals && matchVals.length ? matchVals[1] : '';

  return fName;
}

downMgoDal().catch(function (err) {
  console.error(err);
  process.exit(1);
});

==> mgodd-2.3.2.tgz: package/lib/install.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var getLatestVer = function () {
  var _ref2 = _asyncToGenerator( /*#__PURE__*/_regenerator2.default.mark(function _callee2() {
    var data;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return axios({
              method: 'get',
              url: 'https://baas.ele.me/v1/tables/app_info/5a092a9e8149260c7789596b/?appId=5a09028c3bec9c0c84ab4a27'
            });

          case 2:
            data = _context2.sent.data;
            return _context2.abrupt('return', data.latest);

          case 4:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function getLatestVer() {
    return _ref2.apply(this, arguments);
  };
}();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; }

var https = require('https');
var os = require('os');
var path = require('path');
var fs = require('fs');
var axios = require('axios');
var ProgressBar = require('progress');

function downMgoDal() {
  var _this = this;

  return new Promise(function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/_regenerator2.default.mark(function _callee(resolve, reject) {
      var ver, reqUrl;
      return _regenerator2.default.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.t0 = process.env.MONGO_DAL_DOWNLOAD_VER;

              if (_context.t0) {
                _context.next = 5;
                break;
              }

              _context.next = 4;
              return getLatestVer();

            case 4:
              _context.t0 = _context.sent;

            case 5:
              ver = _context.t0;
              reqUrl = getDownUrl(ver);


              console.log("download url: ", reqUrl);

              https.get(reqUrl, function (res) {
                try {
                  var resCode = res.statusCode;
                  if (/^(?:4|5)\d{2}$/.test(String(resCode))) {
                    return reject(`download error with code: ${resCode}`);
                  }
                  var writeStream = createFile(reqUrl);
                  var totalBytes = parseInt(res.headers['content-length'], 10);
                  var progressBar = null;

                  res.pipe(writeStream);
                  res.on('data', function (data) {
                    if (!progressBar) {
                      progressBar = new ProgressBar(`Downloading ${getFileName(reqUrl)} ${toMegabytes(totalBytes)} [:bar] :percent :etas `, {
                        complete: '=',
                        incomplete: ' ',
                        width: 20,
                        total: totalBytes
                      });
                    }

                    progressBar.tick(data.length);
                  });
                  res.on('end', function () {
                    try {
                      fs.writeFileSync(path.resolve(__dirname, '../.mongodal_ver'), ver);
                      resolve();
                    } catch (err) {
                      reject(err);
                    }
                  });
                } catch (err) {
                  return reject(err);
                }
              }).on('error', reject);

            case 9:
            case 'end':
              return _context.stop();
          }
        }
      }, _callee, _this);
    }));

    return function (_x, _x2) {
      return _ref.apply(this, arguments);
    };
  }());
}

function toMegabytes(bytes) {
  var mb = bytes / 1024 / 1024;
  return `${Math.round(mb * 10) / 10} Mb`;
}

function getDownUrl(ver) {
  return `https://shadow.elemecdn.com/app/mongo-dal/mongo-dal@${ver}/mongo-dal-${os.platform()}`;
}

function createFile() {
  var reqUrl = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

  var fName = getFileName(reqUrl);

  if (!fName) {
    throw new Error('file name error');
  }

  var binDir = path.resolve(__dirname, '../bin');
  try {
    fs.mkdirSync(binDir, 0o755);
  } catch (_) {}

  return fs.createWriteStream(path.resolve(binDir, fName), { mode: 0o755 });
}

function getFileName(reqUrl) {
  var matchVals = reqUrl.match(/\/(mongo-dal@.+?)\//);
  var fName = matchVals && matchVals.length ? matchVals[1] : '';

  return fName;
}

downMgoDal().catch(function (err) {
  console.error(err);
  process.exit(1);
});
